pub enum PartialReason {
Syntax,
InvalidSenderAddress,
InvalidRecipientAddress,
}Expand description
Reason why a command was only partially parsed.
Variants
Syntax
General command syntax error — verb unrecognised, missing prefix, etc.
InvalidSenderAddress
“MAIL FROM:” prefix matched but the sender address failed to parse. The SMTP server should respond with 501 5.1.7.
InvalidRecipientAddress
“RCPT TO:” prefix matched but the recipient address failed to parse. The SMTP server should respond with 501 5.1.3.