Mailbox

Struct Mailbox 

pub struct Mailbox {
    pub domain: Domain,
    /* private fields */
}
An email mailbox: local-part "@" domain

Fields

domain: Domain

Implementations

Source

impl Mailbox

pub fn is_ascii(&self) -> bool

Returns true if both the local part and domain are pure ASCII.

pub fn local_part(&self) -> Cow<'_, str>

Returns the normalized local part. Normalization removes any quoting from the local part, so that "\f\o\o" and "foo" will both be returned as foo and will compare as equal.